import os
import sys

from .Binomialdistribution import Binomial
from .Gaussiandistribution import Gaussian

sys.path.append(os.path.dirname(os.path.realpath(__file__)))

# TODO: import the Binomial class from the Binomialdistribution module
